@@ -7,38 +7,38 @@
 package net.mediaarea.mediainfo
 
 import kotlin.jvm.*
+import kotlinx.coroutines.launch
 
-import java.io.File
-
+import androidx.activity.result.contract.ActivityResultContracts
 import androidx.appcompat.app.AppCompatActivity
-import androidx.recyclerview.widget.RecyclerView
-import androidx.lifecycle.ViewModelProvider
-import androidx.core.app.ActivityCompat
 import androidx.appcompat.app.AppCompatDelegate
+import androidx.core.app.ActivityCompat
+import androidx.core.content.edit
+import androidx.core.net.toUri
+import androidx.core.view.updatePadding
+import androidx.core.view.ViewCompat
+import androidx.core.view.WindowInsetsCompat
+import androidx.lifecycle.Lifecycle
+import androidx.lifecycle.lifecycleScope
+import androidx.lifecycle.repeatOnLifecycle
+import androidx.lifecycle.ViewModelProvider
+import androidx.preference.PreferenceManager.getDefaultSharedPreferences
+import androidx.recyclerview.widget.RecyclerView
 
+import android.annotation.SuppressLint
 import android.os.Build
 import android.os.Bundle
-import android.os.AsyncTask
-import android.os.Environment
-import android.os.ParcelFileDescriptor
 import android.net.Uri
-import android.app.Activity
 import android.content.Intent
-import android.database.Cursor
-import android.provider.OpenableColumns
 import android.widget.FrameLayout
 import android.widget.TextView
-import android.content.Context
 import android.widget.Toast
 import android.content.SharedPreferences
 import android.content.pm.PackageManager
 import android.content.res.Configuration
 import android.content.res.Resources
 import android.view.*
-import androidx.core.view.ViewCompat
-import androidx.core.view.WindowInsetsCompat
-import androidx.core.view.updatePadding
-import androidx.preference.PreferenceManager.getDefaultSharedPreferences
+
 import io.reactivex.disposables.CompositeDisposable
 import io.reactivex.schedulers.Schedulers
 import io.reactivex.android.schedulers.AndroidSchedulers
@@ -64,101 +64,28 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     private lateinit var helloLayoutBinding: HelloLayoutBinding
     private lateinit var subscriptionManager: SubscriptionManager
     private lateinit var reportModel: ReportViewModel
-    private var disposable: CompositeDisposable = CompositeDisposable()
+    private val disposable: CompositeDisposable = CompositeDisposable()
     private var twoPane: Boolean = false
     private var reports: List<Report> = listOf()
-    private var pendingFileUris: MutableList<Uri> = mutableListOf()
+    private val pendingFileUris: MutableList<Uri> = mutableListOf()
 
-    inner class AddFile: AsyncTask<Uri, Int, Boolean>() {
-        override fun onPreExecute() {
-            super.onPreExecute()
+    private val openFile = registerForActivityResult(ActivityResultContracts.GetMultipleContents()) { uris ->
+        if (uris.isNotEmpty())
+            reportModel.addFiles(contentResolver, uris)
+    }
 
-            activityReportListBinding.addButton.hide()
-            val rootLayout: FrameLayout = activityReportListBinding.frameLayout
-            var found = false
-            for (i: Int in rootLayout.childCount downTo 1) {
-                if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
-                    found = true
+    private val startSubscribeActivityForResult = registerForActivityResult(ActivityResultContracts.StartActivityForResult()) { result ->
+        if (result.resultCode == RESULT_OK)
+            Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT).show()
+    }
+
+    private val startShowReportForResult = registerForActivityResult(ActivityResultContracts.StartActivityForResult()) { result ->
+        if (result.resultCode == RESULT_OK) {
+            result.data?.let {
+                val id = it.getIntExtra(Core.ARG_REPORT_ID, -1)
+                if (id != -1 && twoPane)
+                    showReport(id)
             }
-
-            if (!found)
-                View.inflate(this@ReportListActivity, R.layout.spinner_layout, rootLayout)
-        }
-
-        override fun onPostExecute(result: Boolean?) {
-            super.onPostExecute(result)
-
-            activityReportListBinding.addButton.show()
-
-            val rootLayout: FrameLayout = activityReportListBinding.frameLayout
-            for (i: Int in rootLayout.childCount downTo 1) {
-                if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
-                    rootLayout.removeViewAt(i - 1)
-            }
-        }
-
-        override fun doInBackground(vararg params: Uri?): Boolean {
-            for (uri: Uri? in params) {
-                if (uri == null) {
-                    continue
-                }
-
-                var fd: ParcelFileDescriptor? = null
-                var displayName = ""
-
-                when (uri.scheme) {
-                    "content" -> {
-                        if (Build.VERSION.SDK_INT >= 19) {
-                            try {
-                                val cursor: Cursor? = contentResolver.query(uri, null, null, null, null, null)
-                                // moveToFirst() returns false if the cursor has 0 rows
-                                if (cursor != null && cursor.moveToFirst()) {
-                                    // DISPLAY_NAME is provider-specific, and might not be the file name
-                                    val column = cursor.getColumnIndexOrThrow(OpenableColumns.DISPLAY_NAME)
-                                    if (column >= 0) {
-                                        displayName = cursor.getString(column)
-                                    }
-                                    cursor.close()
-                                }
-                            } catch (e: Exception) {
-                            }
-                            try {
-                                fd = contentResolver.openFileDescriptor(uri, "r")
-                            } catch (e: Exception) {}
-                        }
-                    }
-                    "file" -> {
-                        val file = File(uri.path.orEmpty())
-                        try {
-                            fd = ParcelFileDescriptor.open(file, ParcelFileDescriptor.MODE_READ_ONLY)
-                        } catch (e: Exception) {}
-
-                        displayName = uri.lastPathSegment.orEmpty()
-                    }
-                }
-
-                if (fd == null) {
-                    continue
-                }
-
-                val report: ByteArray = Core.createReport(fd.detachFd(), displayName)
-
-                disposable.add(reportModel.insertReport(Report(0, displayName, report, Core.version))
-                        .subscribeOn(Schedulers.io())
-                        .observeOn(AndroidSchedulers.mainThread())
-                        .doOnComplete {
-                            // Don't go to report view when opening multiples files
-                            if (params.size == 1) {
-                                disposable.add(reportModel.getLastId()
-                                        .subscribeOn(Schedulers.io())
-                                        .observeOn(AndroidSchedulers.mainThread())
-                                        .doOnSuccess {
-                                            showReport(it)
-                                        }.subscribe())
-                            }
-                        }.subscribe())
-            }
-            return true
         }
     }
 
@@ -167,7 +94,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         when (requestCode) {
             READ_EXTERNAL_STORAGE_PERMISSION_REQUEST -> {
                 if ((grantResults.isNotEmpty() && grantResults[0] == PackageManager.PERMISSION_GRANTED)) {
-                    AddFile().execute(*(pendingFileUris.toTypedArray()))
+                    reportModel.addFiles(contentResolver, pendingFileUris)
                     pendingFileUris.clear()
                 } else {
                     // Abort all pending request
@@ -187,7 +114,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         handleIntent(intent)
     }
 
-    private fun handleUri(uri: Uri) {
+    private fun handleUri(uri: Uri, isMultiple: Boolean = false) {
         if (uri.scheme == "file") {
             if (Build.VERSION.SDK_INT >= 23) {
                 if (checkSelfPermission(android.Manifest.permission.READ_EXTERNAL_STORAGE) != PackageManager.PERMISSION_GRANTED) {
@@ -199,7 +126,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                 }
             }
         }
-        AddFile().execute(uri)
+        reportModel.addFiles(contentResolver, listOf(uri), isMultiple)
     }
 
     private fun handleIntent(intent: Intent) {
@@ -217,17 +144,29 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                     }
                 }
                 Intent.ACTION_SEND -> {
-                    val uri = intent.getParcelableExtra<Uri>(Intent.EXTRA_STREAM)
+                    val uri =
+                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
+                            intent.getParcelableExtra(Intent.EXTRA_STREAM, Uri::class.java)
+                        } else {
+                            @Suppress("DEPRECATION")
+                            intent.getParcelableExtra(Intent.EXTRA_STREAM)
+                        }
                     if (uri != null) {
                         handleUri(uri)
                         intent.putExtra(OPEN_INTENT_PROCESSED, true)
                     }
                 }
                 Intent.ACTION_SEND_MULTIPLE -> {
-                    val uriList = intent.getParcelableArrayListExtra<Uri>(Intent.EXTRA_STREAM)
+                    val uriList =
+                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.TIRAMISU) {
+                            intent.getParcelableArrayListExtra(Intent.EXTRA_STREAM, Uri::class.java)
+                        } else {
+                            @Suppress("DEPRECATION")
+                            intent.getParcelableArrayListExtra(Intent.EXTRA_STREAM)
+                        }
                     if (uriList != null) {
-                        for (i in uriList) {
-                            handleUri(i)
+                        for (i in uriList.filterNotNull()) {
+                            handleUri(i, true)
                         }
                         intent.putExtra(OPEN_INTENT_PROCESSED, true)
                     }
@@ -242,18 +181,21 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
         when (sharedPreferences?.contains(key)) {
             false, null -> {
-                val oldSharedPreferences = getSharedPreferences(getString(R.string.preferences_key), Context.MODE_PRIVATE)
+                val oldSharedPreferences = getSharedPreferences(getString(R.string.preferences_key), MODE_PRIVATE)
                 if (oldSharedPreferences?.contains(key) == true) {
                     oldSharedPreferences.getString(key, "").let {
                         when (it) {
                             "ON" -> {
-                                oldSharedPreferences.edit()?.remove(key)
-                                sharedPreferences.edit()?.putString(key, "on")?.apply()
+                                oldSharedPreferences.edit {
+                                    remove(key)
+                                    putString(key, "on")
+                                }
                             }
                             "OFF" -> {
-                                oldSharedPreferences.edit()?.remove(key)
-                                sharedPreferences.edit()?.putString(key, "off")?.apply()
-
+                                oldSharedPreferences.edit {
+                                    remove(key)
+                                    putString(key, "off")
+                                }
                             }
                             else -> {
                             }
@@ -266,12 +208,16 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                     sharedPreferences.getBoolean(key, false).let {
                         when (it) {
                             false -> {
-                                sharedPreferences.edit()?.remove(key)
-                                sharedPreferences.edit()?.putString(key, "off")?.apply()
+                                sharedPreferences.edit {
+                                    remove(key)
+                                    putString(key, "off")
+                                }
                             }
                             true -> {
-                                sharedPreferences.edit()?.remove(key)
-                                sharedPreferences.edit()?.putString(key, "on")?.apply()
+                                sharedPreferences.edit {
+                                    remove(key)
+                                    putString(key, "on")
+                                }
                             }
                         }
                     }
@@ -315,7 +261,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             val content = stream.bufferedReader().use(BufferedReader::readText)
             Core.setLocale(content)
         }
-        catch (error: Exception) {
+        catch (_: Exception) {
         }
     }
 
@@ -344,9 +290,19 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
                 } else {
                     val language = it.split("-r")
                     if (language.size > 1) {
-                        Locale(language[0], language[1])
+                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.BAKLAVA) {
+                            Locale.of(language[0], language[1])
+                        } else {
+                            @Suppress("DEPRECATION")
+                            Locale(language[0], language[1])
+                        }
                     } else {
-                        Locale(language[0])
+                        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.BAKLAVA) {
+                            Locale.of(language[0])
+                        } else {
+                            @Suppress("DEPRECATION")
+                            Locale(language[0])
+                        }
                     }
                 }
 
@@ -383,7 +339,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
             val intent = Intent(this@ReportListActivity, ReportDetailActivity::class.java)
             intent.putExtra(Core.ARG_REPORT_ID, id)
 
-            startActivityForResult(intent, SHOW_REPORT_REQUEST)
+            startShowReportForResult.launch(intent)
         }
     }
 
@@ -442,7 +398,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
                         item?.setOnMenuItemClickListener { _ ->
                             val intent = Intent(Intent.ACTION_VIEW)
-                            intent.data = Uri.parse(getString(R.string.subscription_manage_url).replace('|', '&'))
+                            intent.data = getString(R.string.subscription_manage_url).replace('|', '&').toUri()
                             startActivity(intent)
 
                             true
@@ -455,7 +411,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
 
                     item?.setOnMenuItemClickListener { _ ->
                         val intent = Intent(this, SubscribeActivity::class.java)
-                        startActivityForResult(intent, SUBSCRIBE_REQUEST)
+                        startSubscribeActivityForResult.launch(intent)
 
                         true
                     }
@@ -492,42 +448,6 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         return super.onCreateOptionsMenu(menu)
     }
 
-    override fun onActivityResult(requestCode: Int, resultCode: Int, resultData: Intent?) {
-        super.onActivityResult(requestCode, resultCode, resultData)
-
-        if (resultCode == Activity.RESULT_OK) {
-            when (requestCode) {
-                OPEN_FILE_REQUEST -> {
-                    if (Build.VERSION.SDK_INT >= 19) {
-                        if (resultData == null)
-                            return
-
-                        val clipData = resultData.clipData
-                        if (clipData != null) {
-                            val uris: Array<Uri> = Array(clipData.itemCount) {
-                                clipData.getItemAt(it).uri
-                            }
-                            AddFile().execute(*(uris))
-                        } else if (resultData.data != null) {
-                            AddFile().execute(resultData.data)
-                        }
-                    }
-                }
-                SUBSCRIBE_REQUEST -> {
-                    Toast.makeText(applicationContext, R.string.thanks_text, Toast.LENGTH_SHORT).show()
-                }
-                SHOW_REPORT_REQUEST -> {
-                    if (resultData!=null) {
-                        val id = resultData.getIntExtra(Core.ARG_REPORT_ID, -1)
-                        if (id!=-1 && twoPane) {
-                            showReport(id)
-                        }
-                    }
-                }
-            }
-        }
-    }
-
     override fun getReportViewModel(): ReportViewModel {
         return reportModel
     }
@@ -585,14 +505,43 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         val viewModelFactory = Injection.provideViewModelFactory(this)
         reportModel = ViewModelProvider(this, viewModelFactory)[ReportViewModel::class.java]
 
+        lifecycleScope.launch {
+            repeatOnLifecycle(Lifecycle.State.STARTED) {
+                launch {
+                    reportModel.isLoading.collect { isLoading ->
+                        val rootLayout: FrameLayout = activityReportListBinding.frameLayout
+                        if (isLoading) {
+                            activityReportListBinding.addButton.hide()
+                            var found = false
+                            for (i: Int in rootLayout.childCount downTo 1) {
+                                if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
+                                    found = true
+                            }
+                            if (!found)
+                                View.inflate(
+                                    this@ReportListActivity,
+                                    R.layout.spinner_layout,
+                                    rootLayout
+                                )
+                        } else {
+                            activityReportListBinding.addButton.show()
+                            for (i: Int in rootLayout.childCount downTo 1) {
+                                if (rootLayout.getChildAt(i - 1).id == R.id.spinner_layout)
+                                    rootLayout.removeViewAt(i - 1)
+                            }
+                        }
+                    }
+                }
+                launch {
+                    reportModel.navigateToReport.collect { reportId ->
+                        showReport(reportId)
+                    }
+                }
+            }
+        }
+
         activityReportListBinding.addButton.setOnClickListener {
-            val intent = Intent(Intent.ACTION_GET_CONTENT)
-
-            intent.addCategory(Intent.CATEGORY_OPENABLE)
-            intent.type = "*/*"
-            intent.putExtra(Intent.EXTRA_ALLOW_MULTIPLE, true)
-
-            startActivityForResult(intent, OPEN_FILE_REQUEST)
+            openFile.launch("*/*")
         }
         activityReportListBinding.reportListLayout.clearBtn.setOnClickListener {
             disposable.add(reportModel.deleteAllReports()
@@ -682,6 +631,7 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
         disposable.clear()
     }
 
+    @SuppressLint("NotifyDataSetChanged")
     private fun setupRecyclerView(recyclerView: RecyclerView) {
         recyclerView.adapter = ItemRecyclerViewAdapter()
         recyclerView.isNestedScrollingEnabled = false
@@ -727,9 +677,6 @@ class ReportListActivity : AppCompatActivity(), ReportActivityListener {
     }
 
     companion object {
-        const val SHOW_REPORT_REQUEST = 20
-        const val SUBSCRIBE_REQUEST = 30
-        const val OPEN_FILE_REQUEST = 40
         const val READ_EXTERNAL_STORAGE_PERMISSION_REQUEST = 50
         const val OPEN_INTENT_PROCESSED = "net.mediaarea.mediainfo.internal.tag.Intent.Processed"
     }
