@@ -82,13 +82,14 @@ ColumnEditSheet::~ColumnEditSheet() {
 
 void ColumnEditSheet::fillCombobox() {
     combobox->clear();
+    static const QRegularExpression RegEx(";(.*)");
     QString s = wstring2QString(C->Parameters());
     s.replace("\r\n","\n").replace("\r","\n");
     s.remove(0,s.indexOf(stream->currentText()+"\n"));
     s.truncate((s.indexOf("\n\n")==-1?s.size():s.indexOf("\n\n")));
     QStringList sl = s.split("\n");
     sl.removeAt(0);
-    sl.replaceInStrings(QRegularExpression(";(.*)"),"");
+    sl.replaceInStrings(RegEx,"");
     for (int i=0; i<sl.size(); ++i)
         combobox->addItem(sl.at(i),sl.at(i));
     if(stream->itemData(stream->currentIndex()).toInt()==col.stream)
