@@ -23,6 +23,7 @@ public:
         HTML=1,
         XML,
         JSON,
+        CSV,
         GRAPH,
         PBCORE,
         PBCORE2,
@@ -42,7 +43,7 @@ public:
         NB_EXPORT_MODE
     };
 
-    Export(QString filename, int mode, QWidget *parent = 0);
+    Export(const QString& filename, int mode, QWidget *parent = 0);
     ~Export();
     int getExportMode();
     int getExportConfig();
@@ -53,6 +54,17 @@ public:
     QString extensionName(int mode);
     QString name(int mode);
 
+    struct CSV_Options {
+        int Stream_Video{};
+        int Stream_Audio{};
+        int Stream_Text{};
+        int Stream_Other{};
+        QString Quote;
+        QString Separator_Col;
+        QString Separator_Line;
+    };
+    CSV_Options getCSVOptions();
+
 protected:
     void changeEvent(QEvent *e);
 
